==> artist-0.1.1-py3-none-any.whl: artist/sdk.py <==
# Copyright (c) 2023 TheraPanacea. All rights Reserved.
# Unauthorized copying of this file, via any medium is strictly prohibited
# Proprietary and confidential
"""A client for the ART platform. Wraps HTTP calls."""
import logging
from typing import Any, Dict, List, Optional, Union

import yaml

from artist import client as client_lib

Results = Optional[Dict[str, List[str]]]


def _read_sdk_results(resp) -> Results:
    """Reads HTTP response from the sdk."""
    if resp.status_code == 200:
        result = resp.json()
        if result is None:
            return None

        if result.get('error') == 'False':
            return result['uris']
        else:
            logging.error(result['error'])
    return


def launch(
    client: client_lib.ARTClient,
    operator: str,
    data_ids: Dict[str, str],
    outputs: Union[str, List[Dict[str, str]]],
    params: Optional[Dict[str, Any]] = None,
    yaml_params: Optional[str] = None,
) -> Optional[str]:
    """Launches an operator on some data uids on the sdk."""
    if isinstance(outputs, str):
        outputs = [{'name': k, 'format': outputs} for k in data_ids]
    if params is None:
        params = yaml.safe_load(yaml_params) if yaml_params else {}
    yaml.safe_load(yaml_params)
    payload = {'data_ids': data_ids, 'op_params': params, 'outputs': outputs}
    sdk_root = client.service('sdk')
    resp = client.post(sdk_root, f'{operator}', json=payload, timeout=20)
    if resp.status_code == 200:
        return resp.text
    else:
        logging.error('Cannot launch %s', operator)


def wait_results(
    client: client_lib.ARTClient,
    wf_uid: str,
    timeout: float = 20.0,
    num_retries: int = 20,
) -> Results:
    """Waits for the results of a workflow to be ready and return them."""
    sdk_root = client.service('sdk')
    for _ in range(num_retries):
        try:
            resp = client.get(
                sdk_root, f'/workflow/{wf_uid}/wait-results', timeout=timeout
            )
        except Exception:  # pylint: disable=broad-except
            print('Waiting for results...')
            resp = None
            continue
        break
    return _read_sdk_results(resp) if resp is not None else None


def get_results(client: client_lib.ARTClient, wf_uid: str) -> Results:
    """If available, returns the result of a workflow."""
    sdk_root = client.service('sdk')
    r = client.get(sdk_root, f'workflow/{wf_uid}/results')
    return _read_sdk_results(r)

==> artist-0.1.2-py3-none-any.whl: artist/sdk.py <==
# Copyright (c) 2023 TheraPanacea. All rights Reserved.
# Unauthorized copying of this file, via any medium is strictly prohibited
# Proprietary and confidential
"""A client for the ART platform. Wraps HTTP calls."""
import logging
from typing import Any

import yaml

from artist import client as client_lib

Results = dict[str, list[str]] | None


def _read_sdk_results(resp) -> Results:
    """Reads HTTP response from the sdk."""
    if resp.status_code == 200:
        result = resp.json()
        if result is None:
            return None

        if result.get('error') == 'False':
            return result['uris']
        else:
            logging.error(result['error'])
    return


def launch(
    client: client_lib.ARTClient,
    operator: str,
    data_ids: dict[str, str],
    outputs: str | list[dict[str, str]],
    params: dict[str, Any] = None,
    yaml_params: str | None = None,
) -> str | None:
    """Launches an operator on some data uids on the sdk."""
    if isinstance(outputs, str):
        outputs = [{'name': k, 'format': outputs} for k in data_ids]
    if params is None:
        params = yaml.safe_load(yaml_params) if yaml_params else {}
    payload = {'data_ids': data_ids, 'op_params': params, 'outputs': outputs}
    sdk_root = client.service('sdk')
    resp = client.post(sdk_root, f'{operator}', json=payload, timeout=20)
    if resp.status_code == 200:
        return resp.text
    else:
        logging.error(
            'Cannot launch %s, got error %d: %s', operator, resp.status_code,
            resp.text
        )


def wait_results(
    client: client_lib.ARTClient,
    wf_uid: str,
    timeout: float = 20,
    num_retries: int = 20,
) -> Results:
    """Waits for the results of a workflow to be ready and return them."""
    sdk_root = client.service('sdk')
    for _ in range(num_retries):
        try:
            resp = client.get(
                sdk_root, f'/workflow/{wf_uid}/wait-results', timeout=timeout
            )
        except Exception:  # pylint: disable=broad-except
            print('Waiting for results...')
            resp = None
            continue
        break
    return _read_sdk_results(resp) if resp is not None else None


def get_results(client: client_lib.ARTClient, wf_uid: str) -> Results:
    """If available, returns the result of a workflow."""
    sdk_root = client.service('sdk')
    r = client.get(sdk_root, f'workflow/{wf_uid}/results')
    return _read_sdk_results(r)
